==> powertools-1.0.tar.bz2: lwp_si_packages/xoops/2.0.3/dAPI.py <==
import deployables_lib as dl
import urlparse
import shutil
import os

dl.load_msgs_module("DSP_SHORTNAME-DSP_VERSION", symtab = globals())

dir_moves = [('DSP_SHORTNAME-DSP_VERSION/html', ''),
             ('DSP_SHORTNAME-DSP_VERSION', 'docs')]
file_mods = [{'path' : 'templates_c/', 'delete' : ''}]
secure_files = [('mainfile.php', 0400, 0444), ('uploads', 0700, 0777),
                ('templates_c', 0700, 0777), ('cache', 0700, 0777)]
instance_patches = []

pat = "^\s*define\('(?P<key>[^']+)'\s*,\s*(?P<value>'.*')\)\s*;(?P<comment>\s*/\*.*)?\s*$"
sub = "define('%(key)s',%(value)s);%(comment)s"

def install(site, site_conf, instance_conf, msgs):

    actions = ['resolve_location', 'check_disk_quota', 'check_mysql_enabled', 
	       'check_pass', 'check_install_loc_owner', '']
    args_dict = {}
    dl.do_install_actions(site, site_conf, instance_conf, msgs,
                          globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        actions = ['db_create', 'db_probe', 'archive_unpack', 'check_index',
                   'exec_php_script', 'exec_php_script2', 'exec_php_script3',
                   'handle_security_mode', 'remove_files', 'access_url']
        args_dict = {
            'archive_unpack':       {'dir_moves': dir_moves},
            'handle_security_mode': {'files': secure_files},
            'exec_php_script' : {
                 'script' : 'install/index.php',
                 'args' : {'op' : 'dbsave',
                           'root_path' : 
                               (instance_conf['install_loc'], dl.MODSTR_JAIL),
                           'xoops_url' : instance_conf['url_loc'],
                           'database' : 'mysql',
                           'prefix' : 'xoops',
                           'dbhost' : dl.get_mysql_host(site),
                           'dbuname' : site_conf['mysql']['dbaseadmin'],
                           'dbpass' : instance_conf['dbpass'],
                           'dbname' : instance_conf['dbname'],
                           'db_pconnect' : '0'}, 
                 'success_re' : '.*data has been saved successfully'},
            'exec_php_script2' : {
                 'script' : 'install/index.php',
                 'args' : {'op' : 'createTables'},
                 'success_re' : '.*Database tables created'},
            'exec_php_script3' : {
                 'script' : 'install/index.php',
                 'args' : {'op' : 'insertData',
                           'adminname' : instance_conf['instance_admin'],
                           'adminpass' : instance_conf['instance_pass1'],
                           'adminpass2' : instance_conf['instance_pass1'],
                           'adminmail' : instance_conf['instance_admin_email']},
                 'success_re' : '.*finish >>'},
            'remove_files': { 'files': ['install/'] },
            }
        dl.do_install_actions(site, site_conf, instance_conf, msgs,
                              globals(), actions, args_dict)

def reconfigure(context, site, site_conf, old_site_conf, instance_conf,
                old_instance_conf, msgs):

    actions = ['handle_url_loc', 'resolve_location', '', 'archive_unpack',
               'handle_username_change', 'handle_db_changes']
    args_dict = {
            'archive_unpack':       { 'dir_moves': dir_moves,
                                      'fileinfo' :
                                      {'excluded_files' :
                                       ['mainfile.php', 'install']}},
            }
    if context != dl.CONTEXT_SITE_EDIT and instance_conf.get('dbpass'):
        actions.insert(0, 'db_probe')
        args_dict['db_probe'] = {'use_old' : 1}
    dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                              instance_conf, old_instance_conf, msgs,
                              globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        old_root = "%s%s" % (dl.site_fs_jail(site, old_site_conf),
                             instance_conf['install_loc'])
        new_root = "%s%s" % (dl.site_fs_jail(site, site_conf),
                             instance_conf['install_loc'])        
        vars = [('XOOPS_ROOT_PATH', new_root, old_root),
                ('XOOPS_URL', instance_conf['url_loc'],
                              old_instance_conf['url_loc'])]
        if dl.mysql_installed(site_conf, old_site_conf):
            vars.extend([('XOOPS_DB_USER', site_conf['mysql']['dbaseadmin'],
                          old_site_conf['mysql']['dbaseadmin']),
                         ('XOOPS_DB_NAME', instance_conf['dbname'],
                          old_instance_conf['dbname'])])
        if context != dl.CONTEXT_SITE_EDIT:
            # We will only change the mysql host if a user specifically
            # invokes reconfigure; we don't want this change to happen
            # during upgrade, when all the sites are edited, but the
            # mysql.sock file hasn't moved yet.
            vars.append(('XOOPS_DB_HOST', dl.get_mysql_host(site)))
            if instance_conf.get('dbpass'):
                vars.append(('XOOPS_DB_PASS', instance_conf['dbpass']))
        actions2 = ['edit_conf_file', 'apply_patch', 'handle_security_mode']
        args_dict = {
            'handle_security_mode': { 'files': secure_files },
            'edit_conf_file' : {'file' : 'mainfile.php', 'lang' : 'php',
                                'pat' : pat, 'sub' : sub, 'vars' : vars},
            'apply_patch' : {'patches' : instance_patches}
            }
        dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                                  instance_conf, old_instance_conf, msgs,
                                  globals(), actions2, args_dict)
        
        
def remove(site, site_conf, instance_conf, msgs):
    dl.db_drop(site, site_conf, instance_conf)
    dl.install_loc_cleanup(site, site_conf, instance_conf, dir_moves,
                           file_mods = file_mods)
    
def get_instance_configuration(context, site, site_conf, instance_conf,
                               old_instance_conf, locale, msgs):
    instance = dl.dsp_create_instance(instance_conf['shortname'],
                                      instance_conf['version'])
    dl.dsp_fill_instance(context, instance, site, site_conf,
                         instance_conf, old_instance_conf,
                         ['dbname', 'username', 'url_net', 'url_path',
                          'domain_to_path', 'instance_admin_email'])
    dl.enable_patches(instance, instance_patches)
    return instance

def regression_test(action, index, test_data):
    return dl.regression_check_index(action, index, test_data,
                                     'Register now!')

==> powertools-1.0.1.tar.bz2: lwp_si_packages/xoops/2.0.16/dAPI.py <==
import deployables_lib as dl
import urlparse
import shutil
import os

dl.load_msgs_module("xoops-2.0.16", symtab = globals())

dir_moves = [('xoops-2.0.16/htdocs', ''),
             ('xoops-2.0.16', 'docs')]
file_mods = [{'path' : 'templates_c/', 'delete' : ''}]
secure_files = [('mainfile.php', 0400, 0444), ('uploads', 0700, 0777),
                ('templates_c', 0700, 0777), ('cache', 0700, 0777)]
instance_patches = []

pat = "^\s*define\('(?P<key>[^']+)'\s*,\s*(?P<value>'.*')\)\s*;(?P<comment>\s*/\*.*)?\s*$"
sub = "define('%(key)s',%(value)s);%(comment)s"

def install(site, site_conf, instance_conf, msgs):

    actions = ['resolve_location', 'check_disk_quota', 'check_mysql_enabled', 
	       'check_pass', 'check_install_loc_owner', '']
    args_dict = {}
    dl.do_install_actions(site, site_conf, instance_conf, msgs,
                          globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        actions = ['db_create', 'db_probe', 'archive_unpack', 'check_index',
                   'exec_php_script', 'exec_php_script2', 'exec_php_script3',
                   'handle_security_mode', 'remove_files', 'access_url']
        args_dict = {
            'archive_unpack':       {'dir_moves': dir_moves},
            'handle_security_mode': {'files': secure_files},
            'exec_php_script' : {
                 'script' : 'install/index.php',
                 'args' : {'op' : 'dbsave',
                           'root_path' : 
                               (instance_conf['install_loc'], dl.MODSTR_JAIL),
                           'xoops_url' : instance_conf['url_loc'],
                           'database' : 'mysql',
                           'prefix' : 'xoops',
                           'dbhost' : dl.get_mysql_host(site),
                           'dbuname' : site_conf['mysql']['dbaseadmin'],
                           'dbpass' : instance_conf['dbpass'],
                           'dbname' : instance_conf['dbname'],
                           'db_pconnect' : '0'}, 
                 'success_re' : '.*data has been saved successfully'},
            'exec_php_script2' : {
                 'script' : 'install/index.php',
                 'args' : {'op' : 'createTables'},
                 'success_re' : '.*Database tables created'},
            'exec_php_script3' : {
                 'script' : 'install/index.php',
                 'args' : {'op' : 'insertData',
                           'adminname' : instance_conf['instance_admin'],
                           'adminpass' : instance_conf['instance_pass1'],
                           'adminpass2' : instance_conf['instance_pass1'],
                           'adminmail' : instance_conf['instance_admin_email']},
                 'success_re' : '.*finish >>'},
            'remove_files': { 'files': ['install/'] },
            }
        dl.do_install_actions(site, site_conf, instance_conf, msgs,
                              globals(), actions, args_dict)

def upgrade(site, site_conf, instance_conf, old_instance_conf, msgs):

    secure_files = [('mainfile.php', 0400, 0444), ('uploads', 0700, 0777),
                ('templates_c', 0700, 0777), ('cache', 0700, 0777)]
    if old_instance_conf['shortname'] == 'xoops' and old_instance_conf['version'] == '2.0.13':
        instance_conf['syncfs'] = '1'
        instance_conf['overwritefiles'] = '1'

        actions = ['do_backup','','archive_unpack','handle_security_mode','remove_files']
        args_dict = {'archive_unpack': { 'dir_moves' : dir_moves,
                     'fileinfo' : {'excluded_files' : ['mainfile.php']}},
                     'handle_security_mode': {'files': secure_files},
		     'remove_files': { 'files': ['install/'] }
                    }

        dl.do_upgrade_actions(site, site_conf, instance_conf,
                  old_instance_conf, msgs,
                  globals(), actions, args_dict)

def reconfigure(context, site, site_conf, old_site_conf, instance_conf,
                old_instance_conf, msgs):

    actions = ['handle_url_loc', 'resolve_location', '', 'archive_unpack',
               'handle_username_change', 'handle_db_changes']
    args_dict = {
            'archive_unpack':       { 'dir_moves': dir_moves,
                                      'fileinfo' :
                                      {'excluded_files' :
                                       ['mainfile.php', 'install']}},
            }
    if context != dl.CONTEXT_SITE_EDIT and instance_conf.get('dbpass'):
        actions.insert(0, 'db_probe')
        args_dict['db_probe'] = {'use_old' : 1}
    dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                              instance_conf, old_instance_conf, msgs,
                              globals(), actions, args_dict)
    if msgs.get_severity() != msgs.ERROR:
        old_root = "%s%s" % (dl.site_fs_jail(site, old_site_conf),
                             instance_conf['install_loc'])
        new_root = "%s%s" % (dl.site_fs_jail(site, site_conf),
                             instance_conf['install_loc'])        
        vars = [('XOOPS_ROOT_PATH', new_root, old_root),
                ('XOOPS_URL', instance_conf['url_loc'],
                              old_instance_conf['url_loc'])]
        if dl.mysql_installed(site_conf, old_site_conf):
            vars.extend([('XOOPS_DB_USER', site_conf['mysql']['dbaseadmin'],
                          old_site_conf['mysql']['dbaseadmin']),
                         ('XOOPS_DB_NAME', instance_conf['dbname'],
                          old_instance_conf['dbname'])])
        if context != dl.CONTEXT_SITE_EDIT:
            # We will only change the mysql host if a user specifically
            # invokes reconfigure; we don't want this change to happen
            # during upgrade, when all the sites are edited, but the
            # mysql.sock file hasn't moved yet.
            vars.append(('XOOPS_DB_HOST', dl.get_mysql_host(site)))
            if instance_conf.get('dbpass'):
                vars.append(('XOOPS_DB_PASS', instance_conf['dbpass']))
        actions2 = ['edit_conf_file', 'apply_patch', 'handle_security_mode']
        args_dict = {
            'handle_security_mode': { 'files': secure_files },
            'edit_conf_file' : {'file' : 'mainfile.php', 'lang' : 'php',
                                'pat' : pat, 'sub' : sub, 'vars' : vars},
            'apply_patch' : {'patches' : instance_patches}
            }
        dl.do_reconfigure_actions(context, site, site_conf, old_site_conf,
                                  instance_conf, old_instance_conf, msgs,
                                  globals(), actions2, args_dict)
        
        
def remove(site, site_conf, instance_conf, msgs):
    dl.db_drop(site, site_conf, instance_conf)
    dl.install_loc_cleanup(site, site_conf, instance_conf, dir_moves,
                           file_mods = file_mods)
    
def get_instance_configuration(context, site, site_conf, instance_conf,
                               old_instance_conf, locale, msgs):
    instance = dl.dsp_create_instance(instance_conf['shortname'],
                                      instance_conf['version'])
    dl.dsp_fill_instance(context, instance, site, site_conf,
                         instance_conf, old_instance_conf,
                         ['dbname', 'username', 'url_net', 'url_path',
                          'domain_to_path', 'instance_admin_email'])
    dl.enable_patches(instance, instance_patches)
    return instance

def regression_test(action, index, test_data):
    return dl.regression_check_index(action, index, test_data,
                                     'Register now!')
